<?php

/**
 * @file
 * Contains the Juicebox views style plugin.
 */


/**
 * Style plugin to render each item in a views list.
 *
 * @ingroup views_style_plugins
 */
class juicebox_style_plugin extends views_plugin_style {
  function option_definition() {
    $options = parent::option_definition();
    $options = array(
      'image_field' => array('default' => ''),
      'image_field_style' => array('default' => ''),
      'thumb_field' => array('default' => ''),
      'thumb_field_style' => array('default' => 'thumbnail'),
      'title_field' => array('default' => ''),
      'caption_field' => array('default' => ''),
      'show_title' => array('default' => 0),
      'jlib_galleryWidth' => array('default' => '100%'),
      'jlib_galleryHeight' => array('default' => '100%'),
      'jlib_backgroundColor' => array('default' => '#222222'),
      'jlib_textColor' => array('default' => 'rgba(255,255,255,1)'),
      'jlib_thumbFrameColor' => array('default' => 'rgba(255,255,255,.5)'),
      'jlib_showOpenButton' => array('default' => 1),
      'jlib_showExpandButton' => array('default' => 1),
      'jlib_showThumbsButton' => array('default' => 1),
      'jlib_useThumbDots' => array('default' => 0),
      'jlib_useFullscreenExpand' => array('default' => 0),
      'manual_config' => array('default' => ''),
      'custom_parent_classes' => array('default' => ''),
    );
    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    // Get the active field options
    $fields_options = array();
    $field_options_images = array();
    $field_handlers = $this->display->handler->get_handlers('field');
    foreach ($field_handlers as $field => $handler) {
      if ($label = $handler->label()) {
        $name = $label;
      }
      else {
        $name = $handler->ui_name();
      }
      // Separate image fields from non-image fields
      if (isset($handler->field_info['type'])) {
        if ($handler->field_info['type'] == 'image') {
          $field_options_images[$field] = $name;
        }
        else {
          $field_options[$field] = $name;
        }
      }
      else {
        $field_options[$field] = $name;
      }
    }
    // Get available image style presets
    $presets = image_style_options(FALSE);
    // Initialize the "settings" values before working with them. This is
    // required for legacy support.
    $settings = _juicebox_init_display_settings($this->options);

    $form['image_field'] = array(
      '#type' => 'select',
      '#title' => t('Main Image Field'),
      '#default_value' => $settings['image_field'],
      '#description' => t('The field from the view that should be used for each image in the gallery. This must be an "image" field.'),
      '#options' => $field_options_images,
    );
    $form['image_field_style'] = array(
      '#type' => 'select',
      '#title' => t('Main Image Field Style'),
      '#default_value' => $settings['image_field_style'],
      '#description' => t('The style formatter for the image. Any formatting settings configured on the field itself will be ignored and this style setting will always be used.'),
      '#options' => $presets,
      '#empty_option' => t('None (original image)'),
    );
    $form['thumb_field'] = array(
      '#type' => 'select',
      '#title' => t('Thumbnail Field'),
      '#default_value' => $settings['thumb_field'],
      '#description' => t('The field from the view that should be used for each thumbnail in the gallery. This must be an "image" field. Typically you will simply choose the same value that you set in the "Main Image Field" option above.'),
      '#options' => $field_options_images,
    );
    $form['thumb_field_style'] = array(
      '#type' => 'select',
      '#title' => t('Thumbnail Field Style'),
      '#default_value' => $settings['thumb_field_style'],
      '#description' => t('The style formatter for the thumbnail. Any formatting settings configured on the field itself will be ignored and this style setting will always be used.'),
      '#options' => $presets,
      '#empty_option' => t('None (original image)'),
    );
    $form['title_field'] = array(
      '#type' => 'select',
      '#title' => t('Title Field'),
      '#default_value' => $settings['title_field'],
      '#description' => t('The field from the view that should be used for the title of each image in the gallery. The raw markup generated by views will be used so any formatting settings configured on the field itself will be respected.'),
      '#options' => $field_options,
      '#empty_option' => t('None'),
    );
    $form['caption_field'] = array(
      '#type' => 'select',
      '#title' => t('Caption Field'),
      '#default_value' => $settings['caption_field'],
      '#description' => t('The field from the view that should be used for the caption of each image in the gallery. The raw markup generated by views will be used so any formatting settings configured on the field itself will be respected.'),
      '#options' => $field_options,
      '#empty_option' => t('None'),
    );
    $form['show_title'] = array(
      '#type' => 'checkbox',
      '#title' => t('Show Gallery Title'),
      '#default_value' => $settings['show_title'],
      '#description' => t('Show the view display title as the gallery title (leave unchecked to display no gallery title).'),
    );
    // Also add the "common" form elements.
    $parents_root = array('style_options');
    $form = _juicebox_common_form_elements($form, $settings, $parents_root);
  }

  function validate() {
    // Make sure the pager is not enabled.
    $errors = parent::validate();
    if ($this->display->handler->use_pager()) {
      $errors[] = t('The Juicebox style cannot be used with a pager. Disable the "Use pager" option for this display.');
    }
    return $errors;
  }

}
